/*
 *  jDTAUS Core RI Client Container
 *  Copyright (c) 2005 Christian Schulte
 *
 *  Christian Schulte, Haldener Strasse 72, 58095 Hagen, Germany
 *  <cs@jdtaus.org> (+49 2331 3543887)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.core.container.ri.client;

import java.util.Locale;
import org.jdtaus.core.container.Implementation;

/**
 * Gets thrown for cyclic dependency graphs.
 *
 * @author <a href="mailto:cs@schulte.it">Christian Schulte</a>
 * @version $Id: DependencyCycleException.java 4982 2008-07-04 07:21:54Z schulte2005 $
 *
 * @see DefaultContainer
 */
public class DependencyCycleException extends IllegalStateException
{
    //--Constants---------------------------------------------------------------

    /** Serial version UID for backwards compatibility with 1.1.x classes. */
    private static final long serialVersionUID = -584783384866017144L;

    //---------------------------------------------------------------Constants--
    //--Constructors------------------------------------------------------------

    /**
     * Creates a new {@code DependencyCycleException} taking the involved
     * implementations.
     *
     * @param impl1 the first implementation introducing a cycle.
     * @param impl2 the second implementation introducing a cycle.
     *
     * @throws NullPointerException if either {@code impl1} or {@code impl2}
     * is {@code null}.
     */
    public DependencyCycleException( final Implementation impl1,
                                      final Implementation impl2 )
    {
        super( DependencyCycleExceptionBundle.getInstance().
               getDependencyCycleMessage( Locale.getDefault() ).
               format( new Object[] {
                       impl1.getIdentifier(),
                       impl2.getIdentifier()
                   } ) );

        this.implementations = new Implementation[] { impl1, impl2 };
    }

    //------------------------------------------------------------Constructors--
    //--DependencyCycleException------------------------------------------------

    /**
     * The implementations introducing a cycle.
     * @serial
     */
    private Implementation[] implementations;

    /**
     * Gets the implementation introducing a cycle.
     *
     * @return the implementations introducing a cycle.
     */
    public Implementation[] getImplementations()
    {
        return this.implementations;
    }

    //------------------------------------------------DependencyCycleException--
}
